==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/authorization/Authorization.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.authorization;

import java.util.concurrent.atomic.AtomicReference;


public final class Authorization {

    private static final AtomicReference<AuthorizationService> SERVICE_REF = new AtomicReference<AuthorizationService>();

    /**
     * Default constructor.
     */
    private Authorization() {
        super();
    }

    /**
     * @return the service
     */
    public static AuthorizationService getService() {
        return SERVICE_REF.get();
    }

    /**
     * @param service the service to set
     */
    public static boolean setService(final AuthorizationService service) {
        return SERVICE_REF.compareAndSet(null, service);
    }

    /**
     * @param service the service to set
     */
    public static boolean dropService(final AuthorizationService service) {
        return SERVICE_REF.compareAndSet(service, null);
    }

}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.server/src/com/openexchange/authorization/Authorization.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.authorization;

import java.util.concurrent.atomic.AtomicReference;

/**
 * A utility class that provides {@link #getService() static access} to the tracked instance of {@link AuthorizationService}.
 */
public final class Authorization {

    private static final AtomicReference<AuthorizationService> SERVICE_REF = new AtomicReference<AuthorizationService>();

    /**
     * Default constructor.
     */
    private Authorization() {
        super();
    }

    /**
     * Gets the tracked instance of {@code AuthorizationService}.
     *
     * @return The service or <code>null</code> if no instance of <code>AuthorizationService</code> appeared yet
     */
    public static AuthorizationService getService() {
        return SERVICE_REF.get();
    }

    /**
     * Sets the given service instance.
     *
     * @param service The service to set
     * @return <code>true</code> if given service instance could be successfully set; otherwise <code>false</code> if a concurrent modification occurred
     */
    public static boolean setService(final AuthorizationService service) {
        return SERVICE_REF.compareAndSet(null, service);
    }

    /**
     * Unsets the given service in case that service is currently active.
     *
     * @param service The service to unset
     * @return <code>true</code> if service could be successfully unset; otherwise <code>false</code>
     */
    public static boolean dropService(final AuthorizationService service) {
        return SERVICE_REF.compareAndSet(service, null);
    }

}
